componenttools.get_first_component_with_name_in_improper_parentage_of_component
===============================================================================

.. autofunction:: abjad.tools.componenttools.get_first_component_with_name_in_improper_parentage_of_component.get_first_component_with_name_in_improper_parentage_of_component
